Checking PKCE code verifier strings.
Enums
- Error
- Represents sources of errors that can occur when checking strings.
Functions
- check
- Similar to
check_str, except it is generic overAsRef<str>. - check_
str - Iterarively checks that the given string contains valid characters only.
- const_
check_ str - Recursively checks that the given string contains valid characters only.