Function const_check_str

pub const fn const_check_str(string: &str) -> Result<(), Error>
Recursively checks that the given string contains valid characters only.

One may need to increase the recursion limit manually to use this const function.

This is done via applying the recursion_limit attribute to the crate:

#![recursion_limit = "256"]

Errors

Returns Error on non-ASCII or otherwise invalid strings.