Module length

PKCE code verifier lengths.

As per the standard, the length of the code verifier must be at least 43 and at most 128.

This module provides the Length type, representing the actual length of the code verifier.

The Length type internally stores usize values, which are guaranteed to be in the range from MIN to MAX inclusively, defaulting to DEFAULT.

use pkce_std::length::Length;

let length = Length::new(128);

Structs

Error
Represents errors that can occur when constructing Length values.
Length
Represents lengths.

Enums

ParseError
Represents sources of errors that can occur when parsing Length values.

Constants

DEFAULT
The default length.
MAX
The maximum length.
MIN
The minimum length.