Struct Verifier

pub struct Verifier<'v> { /* private fields */ }
Represents PKCE code verifiers.

Refer to the module documentation for more information.

Examples

use pkce_std::verifier::Verifier;

let string = "dGhhbmtzIGZvciByZWFkaW5nIGRvY3MhIH4gbmVraXQ";

let expected = Verifier::borrowed(string).unwrap();

let bytes = "thanks for reading docs! ~ nekit";

let verifier = Verifier::encode(bytes).unwrap();

// `verifier` and `expected` are compared in constant time!
assert_eq!(verifier, expected);

Implementations

Source

impl Verifier<'_>

pub fn get(&self) -> &str

Returns the borrowed string.

Source

impl Verifier<'_>

pub fn generate(length: Length) -> Self

Generates random Self with specified length.

pub fn generate_default() -> Self

Generates random Self with default length.

pub fn generate_encode(count: Count) -> Self

Generates count random bytes length and encodes them into Self.

pub fn generate_encode_default() -> Self

Generates random bytes of default length and encodes them into Self.

Source

impl Verifier<'_>

pub fn challenge_using(&self, method: Method) -> Challenge

Computes the Challenge of Self with the given Method.

pub fn challenge(&self) -> Challenge

Computes the Challenge of Self with the default Method.

pub fn verify(&self, challenge: &Challenge) -> bool

Verifies the given Challenge against Self.

Source

impl<'v> Verifier<'v>

pub fn new(value: Cow<'v, str>) -> Result<Self, Error>

Constructs Self, provided that the given value is valid.

Errors

See Self::check for more information.

pub const unsafe fn new_unchecked(value: Cow<'v, str>) -> Self

Constructs Self without checking the value.

Safety

The caller must ensure that value is valid for Self.

The value can be checked using Self::check.

pub fn borrowed(value: &'v str) -> Result<Self, Error>

Constructs Self from borrowed value, provided it is valid.

Errors

See Self::new for more information.

pub const unsafe fn borrowed_unchecked(value: &'v str) -> Self

Constructs Self from borrowed value without checking it.

Safety

See Self::new_unchecked for more information.

pub fn owned(value: String) -> Result<Self, Error>

Constructs Self from owned value, provided it is valid.

Errors

See Self::new for more information.

pub const unsafe fn owned_unchecked(value: String) -> Self

Constructs Self from owned value without checking it.

Safety

See Self::new_unchecked for more information.

pub const fn const_borrowed(value: &'v str) -> Result<Self, Error>

Similar to borrowed, but can be used in const contexts.

Note

One may need to increase the recursion limit when using longer strings.

This is done via applying the recursion_limit attribute to the crate:

#![recursion_limit = "256"]
Errors

See const_check_str for more information.

pub const fn const_borrowed_ok(value: &'v str) -> Option<Self>

Similar to const_borrowed, but errors are discarded.

pub const fn const_check_str(string: &str) -> Result<(), Error>

Constantly checks if the given string is valid for Self.

Note

One may need to increase the recursion limit when checking longer strings.

This is done via applying the recursion_limit attribute to the crate:

#![recursion_limit = "256"]
Errors

Returns Error if the string is invalid, which means either:

pub fn check_str(string: &str) -> Result<(), Error>

Checks if the given string is valid for Self.

Errors

Returns Error if the string is invalid, which means either:

pub fn check<S: AsRef<str>>(value: S) -> Result<(), Error>

Similar to check_str, except it is generic over AsRef<str>.

Errors

Any Error returned by check_str is propagated.

pub fn take(self) -> Cow<'v, str>

Consumes Self and returns the contained string.

Source

impl Verifier<'_>

pub fn encode<B: AsRef<[u8]>>(bytes: B) -> Result<Self, Error>

Encodes the given bytes into Self, provided bytes has valid length.

Errors

Returns count::Error if the length of bytes is invalid.

pub unsafe fn encode_unchecked<B: AsRef<[u8]>>(bytes: B) -> Self

Encodes the given bytes into Self without checking bytes length.

Safety

The caller must ensure that bytes has valid length.

The bytes can be checked using Count::check on its length.